{ pkgs, config, lib, ... }:

let h = config.home.homeDirectory;
in {
  home.packages = with pkgs; [ steam minecraft fahcontrol ];

  services.mpd = {
    enable = true;
    musicDirectory = h + "/Music/Best";
    network.listenAddress = "any";
    extraConfig = ''
      audio_output {
        type "pulse"
        name "Shared output (pulseaudio)"
        format "96000:32:*"
      }

      audio_output {
        type "jack"
        name "Jack output"
      }
    '';
  };
  programs.ncmpcpp.enable = true;
  services.mpdris2 = {
    enable = true;
    mpd.host = "127.0.0.1";
  };

  programs.kitty.settings.font_size = lib.mkForce "14.0";

  wayland.windowManager.sway = let
    outputs = {
      main = "Samsung Electric Company C27JG5x H4ZMA00132";
      alt = "Unknown HP E233 CNC7500L7Q";
    };
    mod = config.wayland.windowManager.sway.config.modifier;
  in {
    config = {
      keybindings = {
        "${mod}+Ctrl+slash" = ''output "${outputs.alt}" toggle'';
        "${mod}+Shift+slash" =
          ''output "${outputs.alt}" transform 90 anticlockwise'';
      };

      output = {
        "${outputs.main}" = {
          resolution = "2560x1440@144Hz";
          position = "0 0";
        };
        "${outputs.alt}" = {
          resolution = "1920x1080@60Hz";
          position = "2560 180";
        };
      };
    };
    extraConfig = ''
      workspace 10 output "${outputs.alt}" "${outputs.main}"
    '';
  };
}
