{ config, lib, pkgs, ... }:

with lib;

let
  cfg = config.programs.gopass;
  yamlFormat = pkgs.formats.yaml { };
in {
  options = {
    programs.gopass = {
      enable = mkEnableOption "gopass";

      jsonAPI.enable = mkEnableOption "gopass-jsonapi";

      password-store = mkOption {
        type = types.str;
        default = "~/.local/share/gopass/stores/root";
        example = "~/Dropbox/Passwords";
        description = "The path to the password store.";
      };

      settings = mkOption {
        type = yamlFormat.type;
        default = { };
        example = { nocolor = true; };
        description = "An attribute set of additional settings.";
      };
    };
  };

  config = mkIf cfg.enable {
    home.packages = [ pkgs.gopass ] ++ (optional cfg.jsonAPI.enable pkgs.gopass-jsonapi);

    xdg.enable = true;
    xdg.configFile."gopass/config.yml".source =
      yamlFormat.generate "gopass-config.yml"
      (cfg.settings // { path = cfg.password-store; });
  };
}
