{ config, lib, pkgs, ... }:

with lib;

let
  cfg = config.programs.wal;
  walCmd = pkgs.pywal + /bin/wal;

  shellSequences = "~/.cache/wal/sequences";
  shellActivate = ''
    [ -f ${shellSequences} ] && (cat ${shellSequences} &)
  '';
in {
  options = {
    programs.wal = {
      enable = mkEnableOption "wal";
      background = mkOption {
        type = types.either types.str types.path;
        example = "~/Pictures/wallpaper.jpg";
        description = "The path to the chosen wallpaper image.";
      };
      backend = mkOption {
        type = types.str;
        default = "wal";
        example = "colorthief";
        description = "The colorscheme-generating backend to use.";
      };

      shell.enable = mkEnableOption "wal shell integration";
      sway.enable = mkEnableOption "wal sway integration";
      sway.bgMode = mkOption {
        type = types.str;
        default = "fill";
        example = "stretch";
        description = "The scaling mode to use for sway background.";
      };
    };
  };

  config = mkIf cfg.enable {
    home = {
      packages = [ pkgs.pywal ];
      activation = {
        # Must be before onFilesChange because that's when other configs are reloaded
        updateWalScheme =
          lib.hm.dag.entryBetween [ "onFilesChange" ] [ "writeBoundary" ] ''
            ${walCmd} -i ${cfg.background} --backend ${cfg.backend} -e -s -t
          '';
      };
    };

    programs.zsh.initExtra = mkIf cfg.shell.enable shellActivate;
    programs.bash.initExtra = mkIf cfg.shell.enable shellActivate;

    wayland.windowManager.sway = mkIf cfg.sway.enable {
      config.output."*".bg = "${cfg.background} ${cfg.sway.bgMode}";
    };
  };
}
