{ config, pkgs, lib, ... }:

with lib;

{
  imports = [ ./appearance.nix ];

  home.keyboard = {
    layout = "us";
    options = [ "ctrl:nocaps" "compose:ralt" ];
  };

  xsession.enable = true;

  home.packages = with pkgs;
    let
      gn = pkgs.gnome3;
      evolution = pkgs.evolutionWithPlugins.override {
        plugins = [ pkgs.evolution pkgs.evolution-ews ];
      };
    in [
      feh
      betterlockscreen
      xclip

      gn.gnome-tweaks
      mate.atril
      mate.caja
      libreoffice-fresh
      inkscape
      krita
      nyxt
      lagrange
      tor-browser-bundle-bin
      evolution
      calibre
      obsidian
      flameshot
      gitkraken
      discord
      keybase-gui

      openshot-qt
      blender
      asunder
      gn.cheese
      vlc
      v4l-utils
      handbrake
      darktable
      pavucontrol
      vorbis-tools
      audacity
      pulseaudio
      jack2
      cadence
      helvum
      blueman
      blanket

      signal-desktop
      slack
      teams
      zoom-us

      winePackages.full

      nextcloud-client

      iosevka
      fira
      fira-code
      merriweather
      gentium
      gentium-book-basic
      open-sans
      joypixels
      noto-fonts-emoji
      font-awesome
      emojione
      league-of-moveable-type
      corefonts
      vistafonts
      carlito
      caladea
    ];

  home.activation = {
    installFace = lib.hm.dag.entryAfter [ "writeBoundary" ] ''
      $DRY_RUN_CMD cp --force --dereference --no-preserve=ownership $VERBOSE_ARG \
          ${./images/cat.jpg} $HOME/.face
    '';
  };
  xdg.configFile = {
    "wofi".source = ./wofi;
    "kitty/sessions/default.conf".text = ''
      layout tall
      launch ${pkgs.ncmpcpp}/bin/ncmpcpp
      launch ${pkgs.bpytop}/bin/bpytop

      new_tab

      layout tall
      cd ~
    '';
    "waybar".source = ./waybar;
  };

  home.activation = {
    updateFcCache = lib.hm.dag.entryAfter [ "writeBoundary" ] ''
      $DRY_RUN_CMD fc-cache -f
    '';
  };

  fonts.fontconfig.enable = true;

  programs.mako = {
    enable = true;
    defaultTimeout = 10000;
  };

  programs.waybar = {
    enable = true;
    systemd.enable = true;
  };

  services.gammastep = {
    enable = false;
    provider = "manual";
    latitude = 54.0;
    longitude = 1.0;
    tray = true;
  };

  services.redshift = {
    enable = true;
    provider = "manual";
    latitude = 54.0;
    longitude = 1.0;
    tray = true;
  };

  programs.kitty = {
    enable = true;
    font = {
      name = "Iosevka Medium";
      package = pkgs.iosevka;
      size = 11;
    };
    settings = {
      allow_remote_control = true;
      listen_on = "unix:\${XDG_RUNTIME_DIR}/kitty.sock";

      enable_audio_bell = false;
      visual_bell_duration = "0.1";
    };
    extraConfig = ''
      include ${./colours/Monokai.conf}
    '';
  };

  programs.rofi = {
    enable = true;
    plugins = [ pkgs.rofi-emoji pkgs.rofi-pass ];
    theme = "gruvbox-dark-soft";
    terminal = pkgs.alacritty + /bin/alacritty;
  };

  programs.chromium = {
    enable = true;
    extensions = [
      { id = "cjpalhdlnbpafiamejdnhcphjbkeiagm"; } # uBlock origin
      { id = "hdokiejnpimakedhajhdlcegeplioahd"; } # LastPass
      { id = "ldgfbffkinooeloadekpmfoklnobpien"; } # raindrop.io
      { id = "kkhfnlkhiapbiehimabddjbimfaijdhk"; } # gopass bridge
      { id = "ldpochfccmkkmhdbclfhpagapcfdljkj"; } # DecentralEyes
    ];
  };

  programs.qutebrowser.enable = true;
  programs.element-desktop.enable = true;

  programs.obs-studio = {
    enable = true;
    plugins = with pkgs.obs-studio-plugins; [ wlrobs ];
  };

  programs.ncmpcpp.settings = { user_interface = "alternative"; };

  services.syncthing.enable = true;
  services.nextcloud-client.enable = true;
}
