{ config, pkgs, lib, ... }:

{
  programs.firefox = {
    enable = true;

    package = pkgs.firefox.override {
      cfg = {
        enableGnomeExtensions = true;
        enableTridactylNative = true;
      };
    };

    extensions = with pkgs.nur.repos.rycee.firefox-addons; [
      # Password management
      lastpass-password-manager
      gopass-bridge

      # Privacy
      https-everywhere
      decentraleyes
      ublock-origin
      privacy-badger
      privacy-possum
      privacy-redirect
      facebook-container
      multi-account-containers
      clearurls

      # Appearance
      darkreader
      firefox-color

      # Other
      unpaywall
      tridactyl
    ];

    profiles.default = {
      settings = {
        "browser.aboutConfig.showWarning" = false;
        "browser.tabs.warnOnClose" = false;
        "browser.toolbars.bookmarks.visibility" = "always";

        "browser.fixup.alternate.enabled" = false;

        "devtools.cache.disabled" = true;

        "layers.acceleration.force-enabled" = true;

        "pdfjs.enableScripting" = false;

        "ui.prefersReducedMotion" = 1;
      };
    };

    profiles.clean = { id = 1; };
  };

  home.packages = [ pkgs.tridactyl-native ];
  home.file.".mozilla/native-messaging-hosts/tridactyl.json".source =
    "${pkgs.tridactyl-native}/lib/mozilla/native-messaging-hosts/tridactyl.json";

  xdg.configFile."tridactyl/tridactylrc".source = ./tridactylrc;
}
