{ config, pkgs, lib, ... }:

{
  imports = [ ./zsh.nix ];

  home.packages = with pkgs; [
    ripgrep
    fd
    fasd
    unzip
    rsync
    pv
    unison
    file
    tree

    curl
    jq

    shellcheck
    rmlint
    progress
    colordiff
    screenfetch
    termdown
  ];

  programs.fzf.enable = true;
  programs.lesspipe.enable = true;
  programs.exa = {
    enable = true;
    enableAliases = true;
  };

  programs.starship = {
    enable = true;
    enableZshIntegration = true;
    settings = {
      time.disabled = false;

      hostname.ssh_only = false;

      git_branch.symbol = "\\[g\\] ";

      hg_branch.disabled = false;
      hg_branch.symbol = "\\[h\\] ";

      format = builtins.concatStringsSep "" [
        "$username"
        "$hostname"
        "$kubernetes"
        "$directory"
        "$git_branch"
        "$git_commit"
        "$git_state"
        "$git_status"
        "$hg_branch"
        "$docker_context"
        "$package"
        "$dotnet"
        "$elixir"
        "$elm"
        "$erlang"
        "$golang"
        "$java"
        "$julia"
        "$nim"
        "$nodejs"
        "$ocaml"
        "$php"
        "$purescript"
        "$python"
        "$ruby"
        "$rust"
        "$terraform"
        "$zig"
        "$nix_shell"
        "$conda"
        "$memory_usage"
        # "$aws"
        "$env_var"
        "$crystal"
        "$cmd_duration"
        "$custom"
        "$time"
        "$line_break"
        "$jobs"
        "$battery"
        "$character"
      ];
    };
  };

  programs.direnv = {
    enable = true;
    nix-direnv.enable = true;
  };

  services.lorri.enable = true;

  programs.command-not-found.enable = true;

}
