{ config, lib, pkgs, ... }:

with lib;

let
  py = pkgs.python38Packages;
  extraXontribs = let inherit (py) buildPythonPackage fetchPypi;
  in {
    direnv = buildPythonPackage rec {
      pname = "xonsh-direnv";
      version = "1.5.0";
      src = fetchPypi {
        inherit pname version;
        sha256 =
          "38b8ed183da55f861fdda1ebc425a601b48f6677fc3ae56b06ed1515bb276b56";
      };
    };

    zoxide = buildPythonPackage rec {
      pname = "xontrib-zoxide";
      version = "0.3.0";
      src = fetchPypi {
        inherit pname version;
        sha256 =
          "6d8b0ef283c415790ef9ef6631f5f2609a5d98af390bdfa1d0f9ad8554d4d826";
      };
      postPatch = "sed -i '/install_requires=/d' setup.py";
    };

    prompt_starship = buildPythonPackage rec {
      pname = "xontrib-prompt-starship";
      version = "0.2.0";
      src = fetchPypi {
        inherit pname version;
        sha256 =
          "ac117f226f38f4c8a1f6bba9352d99d491709bf8062c70c44dd981924d06e0c9";
      };
      postPatch = "sed -i '/install_requires=/d' setup.py";
    };
  };

in {
  home.packages = with pkgs; [ zoxide ];

  programs.xonsh = {
    enable = true;

    sessionVariables = { AUTO_CD = true; };

    shellAliases = {
      ls = "${pkgs.exa}/bin/exa";
      ll = "${pkgs.exa}/bin/exa -l";
      la = "${pkgs.exa}/bin/exa -a";
      lt = "${pkgs.exa}/bin/exa --tree";
      lla = "${pkgs.exa}/bin/exa -la";
      l = "${pkgs.exa}/bin/exa -lah";

      gst = "git status";

      sc = "systemctl";
      scu = "systemctl --user";

      ns = "nix search nixpkgs";
    };

    xontribs = [ "coreutils" "bashisms" ];
    inherit extraXontribs;

    rcExtra = ''
      $PROMPT_FIELDS['prompt_end'] = '@'
    '';
  };

  programs.starship.settings.character = {
    success_symbol = "[@](bold green)";
    error_symbol = "[@](bold red)";
  };
}
