{ config, pkgs, lib, ... }:

{
  imports = [ ./hardware.nix ./backup.nix ];
  profiles = [ "home" "zfs" "amdgpu" ];

  boot.loader = {
    efi = {
      canTouchEfiVariables = false;
      efiSysMountPoint = "/boot/efi";
    };
    grub = {
      enable = true;
      efiSupport = true;
      efiInstallAsRemovable = false;
      device = "nodev";
      gfxmodeEfi = "2560x1440";
      extraConfig = ''
        set timeout=2;
        set timeout_style="menu";
      '';
    };
  };

  virtualisation.docker.storageDriver = "zfs";

  users.users.jez.uid = 1000;
  users.groups.jez.gid = 1000;

  networking.interfaces.enp39s0.useDHCP = true;

  networking.firewall.allowedTCPPorts = [
    6600 # mpd
    21 # ftp
    1313 # Hugo preview
    3000 # various dev web servers
    5000 # nix-serve (see below)
  ];

  hardware.pulseaudio.daemon.config = {
    default-sample-rate = "192000";
    alternate-sample-rate = "96000";
    avoid-resampling = "yes";
  };

  services.vsftpd = {
    enable = true;
    localUsers = true;
    userlist = [ "jez" ];
    writeEnable = true;
  };

  services.nix-serve = {
    enable = true;
    secretKeyFile = "/etc/nix/gwydion.local-1.sec";
    openFirewall = true;
  };
}
